@@ -22,6 +22,7 @@
  *
  */
  
+#include <config.h>
 #include "config-parser-common.h"
 #include "config-parser-trivial.h"
 #include "utils.h"
@@ -163,7 +164,7 @@ bus_config_parser_start_element (BusConfigParser   *parser,
     {
     case ELEMENT_SERVICEHELPER:
     case ELEMENT_USER:
-    case ELEMENT_TYPE:
+    case ELEMENT_CONFIGTYPE:
       /* content about to be handled */
       break;
 
@@ -187,7 +188,7 @@ bus_config_parser_start_element (BusConfigParser   *parser,
     default:
       {
         /* we really don't care about the others... */
-        _dbus_verbose (" START We dont care about '%s' type '%i'\n", element_name, parser->type);
+        _dbus_verbose (" START We don't care about '%s' type '%i'\n", element_name, parser->type);
         break;
       }
     }
@@ -276,7 +277,7 @@ bus_config_parser_content (BusConfigParser   *parser,
       }
       break;
 
-    case ELEMENT_TYPE:
+    case ELEMENT_CONFIGTYPE:
       {
         if (!_dbus_string_copy (&content_sane, 0, &parser->bus_type, 0))
           {
@@ -288,7 +289,7 @@ bus_config_parser_content (BusConfigParser   *parser,
     default:
       {
         /* we don't care about the others... really */
-        _dbus_verbose (" CONTENTS We dont care '%s' type '%i'\n", _dbus_string_get_const_data (&content_sane), parser->type);
+        _dbus_verbose (" CONTENTS We don't care about '%s' type '%i'\n", _dbus_string_get_const_data (&content_sane), parser->type);
         break;
       }
     }
@@ -329,7 +330,7 @@ bus_config_parser_get_service_dirs (BusConfigParser *parser)
   return &parser->service_dirs;
 }
 
-#ifdef DBUS_BUILD_TESTS
+#ifdef DBUS_ENABLE_EMBEDDED_TESTS
 #include <stdio.h>
 #include "test.h"
 
@@ -711,5 +712,5 @@ finish:
   return retval;
 }
 
-#endif /* DBUS_BUILD_TESTS */
+#endif /* DBUS_ENABLE_EMBEDDED_TESTS */
 
