@@ -365,6 +365,11 @@ main (int argc, char *argv[])
       exit (1);
     }
 
+  /* Receive o.fd.Peer messages as normal messages, rather than having
+   * libdbus handle them internally, which is the wrong thing for
+   * a monitor */
+  dbus_connection_set_route_peer_messages (connection, TRUE);
+
   if (numFilters)
     {
       size_t offset = 0;
